abacusai.database_column_feature_mapping — AbacusAI documentation

# abacusai.database_column_feature_mapping

## Classes

`DatabaseColumnFeatureMapping` | Mapping for export of feature group version to database column

## Module Contents

class abacusai.database_column_feature_mapping.DatabaseColumnFeatureMapping(client, databaseColumn=None, feature=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Mapping for export of feature group version to database column

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - databaseColumn (str) – database column name

    - feature (str) – feature group column it has been matched to

  database_column = None
  feature = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict